@@ -222,8 +222,8 @@ as_task.OMLRun = function(x, ...) {
 
 #' @importFrom mlr3 as_data_backend
 #' @export
-as_data_backend.OMLRun = function(x, primary_key = NULL, ...) {
-  as_data_backend(x$data, primary_key = primary_key, ...)
+as_data_backend.OMLRun = function(data, primary_key = NULL, ...) {
+  as_data_backend(data$data, primary_key = primary_key, ...)
 }
 
 #' @importFrom mlr3 as_resampling
